Learn R Programming

qualpalr (version 2.0.0)

qualpalr-package: qualpalr: Automatic Generation of Qualitative Color Palettes

Description

Automatic generation of maximally distinct qualitative color palettes, optionally tailored to color deficiency. A set of colors or a subspace of a color space is used as input and a final palette of specified size is generated by picking colors that maximize the minimum pairwise difference among the chosen colors. Adaptations to color vision deficiency, background colors, and white points are supported.

Arguments

Author

Maintainer: Johan Larsson johan@jolars.co (ORCID)

See Also